@@ -1,9 +1,14 @@
-import sys
-
-from PyObjCTools.TestSupport import *
 import CoreBluetooth
+import objc
+from PyObjCTools.TestSupport import TestCase, min_os_level
 
-class TestCBCentralManager (TestCase):
+
+class TestCBCentralManagerHelper(CoreBluetooth.NSObject):
+    def centralManager_connectionEventDidOccur_forPeripheral_(self, a, b, c):
+        pass
+
+
+class TestCBCentralManager(TestCase):
     @min_os_level("10.9")
     def testClasses(self):
         self.assertHasAttr(CoreBluetooth, "CBCentralManager")
@@ -18,13 +23,23 @@ class TestCBCentralManager (TestCase):
         self.assertEqual(CoreBluetooth.CBCentralManagerStatePoweredOff, 4)
         self.assertEqual(CoreBluetooth.CBCentralManagerStatePoweredOn, 5)
 
+        self.assertEqual(CoreBluetooth.CBConnectionEventPeerDisconnected, 0)
+        self.assertEqual(CoreBluetooth.CBConnectionEventPeerConnected, 1)
+
     @min_os_level("10.9")
     def testProtocols(self):
-        self.assertIsInstance(objc.protocolNamed("CBCentralManagerDelegate"), objc.formal_protocol)
+        self.assertIsInstance(
+            objc.protocolNamed("CBCentralManagerDelegate"), objc.formal_protocol
+        )
 
-    @min_os_level('10.13')
+    @min_os_level("10.13")
     def testMethods10_13(self):
         self.assertResultIsBOOL(CoreBluetooth.CBCentralManager.isScanning)
 
-if __name__ == "__main__":
-    main()
+    @min_os_level("10.15")
+    def testMethods10_15(self):
+        self.assertArgHasType(
+            CoreBluetooth.TestCBCentralManagerHelper.centralManager_connectionEventDidOccur_forPeripheral_,  # noqa: B950
+            1,
+            objc._C_NSInteger,
+        )
